﻿local _, L = ...
local mediaFolder = "Interface\\AddOns\\".._.."\\media\\"

local max = max
local string_match = string.match
local tinsert = tinsert

local LootSlotHasItem = LootSlotHasItem
local CloseLoot = CloseLoot
local CreateFrame = CreateFrame
local CursorOnUpdate = CursorOnUpdate
local CursorUpdate = CursorUpdate
local GetCursorPosition = GetCursorPosition
local GetCVarBool = GetCVarBool
local GetLootSlotInfo = GetLootSlotInfo
local GetLootSlotLink = GetLootSlotLink
local GetNumLootItems = GetNumLootItems
local HandleModifiedItemClick = HandleModifiedItemClick
local IsModifiedClick = IsModifiedClick
local LootSlot = LootSlot
local LootSlotHasItem = LootSlotHasItem
local ResetCursor = ResetCursor
local StaticPopup_Hide = StaticPopup_Hide
local ITEM_QUALITY_COLORS = ITEM_QUALITY_COLORS


-- from ElvUI, ty
local coinTextureIDs = {
	[133784] = true,-- gold
	[133785] = true,-- gold
	[133786] = true,-- silver
	[133787] = true,-- silver
	[133788] = true,-- copper
	[133789] = true,-- copper
}

local LOOT_UPDATE_INTERVAL = 0.5
local DB

lootFrameMixin = {}

local function CreateMyText(self, layer, font, fontsize, outline, align, justify, shadow)
	local text = self:CreateFontString(nil, layer or "OVERLAY")
		text:SetFont(STANDARD_TEXT_FONT, fontsize or 14, outline or "OUTLINE")
		text:SetPoint(align or "CENTER")
		text:SetJustifyH(justify or "CENTER")
		text:SetText(nil)
		text:SetMaxLines(2)
		text:SetHeight(text:GetStringHeight())
		if shadow then
			text:SetShadowColor(0, 0, 0, .6)
			text:SetShadowOffset(1, -1)
		end	
	return text
end

local function SetMyBorderColor(frame, r, g, b, a)
	frame.top:SetVertexColor(r or 0, g or 0, b or 0, a or 1)
	frame.bottom:SetVertexColor(r or 0, g or 0, b or 0, a or 1)
	frame.left:SetVertexColor(r or 0, g or 0, b or 0, a or 1)
	frame.right:SetVertexColor(r or 0, g or 0, b or 0, a or 1)
end

local function CreateMyBackdrop(parent, pixelSize, r_br, g_br, b_br, a_br, bgTexture, r_bg, g_bg, b_bg, a_bg, shadow_offset, r_s, g_s, b_s, a_s)
	local frame = CreateFrame("Frame", nil, parent)
		frame:SetFrameLevel(parent:GetFrameLevel() - 1)
		frame:ClearAllPoints()
		frame:SetAllPoints(parent)
				
		frame.top = frame:CreateTexture(nil, "OVERLAY")
		frame.top:ClearAllPoints()
		PixelUtil.SetPoint(frame.top, "BOTTOMLEFT", frame, "TOPLEFT", 0, 0)
		PixelUtil.SetPoint(frame.top, "BOTTOMRIGHT", frame, "TOPRIGHT", 0, 0)
		PixelUtil.SetHeight(frame.top, pixelSize, 1)
		frame.top:SetTexture("Interface\\Buttons\\WHITE8x8")
		frame.top:Show()
		
		frame.bottom = frame:CreateTexture(nil, "OVERLAY")
		frame.bottom:ClearAllPoints()
		PixelUtil.SetPoint(frame.bottom, "TOPLEFT", frame, "BOTTOMLEFT", 0, 0)
		PixelUtil.SetPoint(frame.bottom, "TOPRIGHT", frame, "BOTTOMRIGHT", 0, 0)
		PixelUtil.SetHeight(frame.bottom, pixelSize, 1)
		frame.bottom:SetTexture("Interface\\Buttons\\WHITE8x8")
		frame.bottom:Show()
		
		frame.left = frame:CreateTexture(nil, "OVERLAY")
		frame.left:ClearAllPoints()
		PixelUtil.SetPoint(frame.left, "TOPRIGHT", frame, "TOPLEFT", 0, pixelSize)
		PixelUtil.SetPoint(frame.left, "BOTTOMRIGHT", frame, "BOTTOMLEFT", 0, -pixelSize)
		PixelUtil.SetWidth(frame.left, pixelSize, 1)
		frame.left:SetTexture("Interface\\Buttons\\WHITE8x8")
		frame.left:Show()
		
		frame.right = frame:CreateTexture(nil, "OVERLAY")
		frame.right:ClearAllPoints()
		PixelUtil.SetPoint(frame.right, "TOPLEFT", frame, "TOPRIGHT", 0, pixelSize)
		PixelUtil.SetPoint(frame.right, "BOTTOMLEFT", frame, "BOTTOMRIGHT", 0, -pixelSize)
		PixelUtil.SetWidth(frame.right, pixelSize, 1)
		frame.right:SetTexture("Interface\\Buttons\\WHITE8x8")
		frame.right:Show()
		
		SetMyBorderColor(frame, r_br, g_br, b_br, a_br)

		if bgTexture then
			frame.bg = frame:CreateTexture(nil, "BACKGROUND")
			frame.bg:ClearAllPoints()
			frame.bg:SetAllPoints(frame)
			frame.bg:SetTexture(bgTexture)
			frame.bg:SetVertexColor(r_bg / 3 or 0, g_bg / 3 or 0, b_bg / 3 or 0, a_bg or 0)
		end
		
		if shadow_offset then
			frame.shadow = CreateFrame("Frame", nil, frame, "BackdropTemplate")
			frame.shadow:SetFrameLevel(parent:GetFrameLevel() - 1)
			frame.shadow:ClearAllPoints()
			frame.shadow:SetPoint("TOPLEFT", frame, "TOPLEFT", -shadow_offset, shadow_offset)
			frame.shadow:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", shadow_offset, -shadow_offset)
			frame.shadow:SetBackdrop({bgFile = nil, edgeFile = mediaFolder.."glowTex", edgeSize = shadow_offset, tile = false, tileSize = 0, insets = 1})
			frame.shadow:SetBackdropBorderColor(r_s, g_s, b_s, a_s)
			frame.shadow:Hide()
		end
		
	return frame
end

local function OnEnter(self)
	local slot = self:GetID()
	local slotType = GetLootSlotType(slot) -- LOOT_SLOT_NONE, LOOT_SLOT_ITEM, LOOT_SLOT_MONEY, LOOT_SLOT_CURRENCY 
	
	if ( slotType == LOOT_SLOT_CURRENCY ) then
		GameTooltip:SetOwner(self, "ANCHOR_BOTTOMRIGHT", 10, -10)
		GameTooltip:SetLootCurrency(slot)
		CursorUpdate(self)
	else
		GameTooltip:SetOwner(self, "ANCHOR_BOTTOMRIGHT", 10, -10)
		GameTooltip:SetLootItem(slot)
		CursorUpdate(self)
	end
	
	self.border.shadow:SetBackdropBorderColor(1, 1, 0)
end

local function OnLeave(self)
	if self.quality and (self.quality > 1) then
		if self.quality == 9 then
			self.border.shadow:SetBackdropBorderColor(1, 0, 0)
		else
			local color = ITEM_QUALITY_COLORS[self.quality]
			self.border.shadow:SetBackdropBorderColor(color.r, color.g, color.b)
		end
	else
		self.border.shadow:SetBackdropBorderColor(0, 0, 0)
	end
	
	GameTooltip:Hide()
	ResetCursor()
end

local function OnClick(self)
--[[	local LootFrame = _G.LootFrame
	LootFrame.selectedQuality = self.quality
	LootFrame.selectedItemName = self.lootName
	LootFrame.selectedSlot = self:GetID()
	LootFrame.selectedLootButton = self:GetName()
	LootFrame.selectedTexture = self.icon:GetTexture()
]]--	
	if IsModifiedClick() then
		HandleModifiedItemClick(GetLootSlotLink(self:GetID()))
	else
		StaticPopup_Hide('CONFIRM_LOOT_DISTRIBUTION')
		LootSlot(self:GetID())
	end
end

local function OnShow(self)
	if GameTooltip:IsOwned(self) then
		GameTooltip:SetOwner(self,"ANCHOR_BOTTOMRIGHT", 10, -10)
		GameTooltip:SetLootItem(self:GetID())
		CursorOnUpdate(self)
	end
end

local function OnLootClosed(self)
	StaticPopup_Hide('LOOT_BIND')
	self:Hide()
	-- pre istotu Hide na vsetky sloty
	for _, frame in pairs(self.slots) do
		frame:Hide()
	end
end

-- uprav zarovnanie pri zmene slot itemov
local function anchorSlots(self)
	local shownSlots = 0
	for i=1, #self.slots do
		self.slots[i]:SetSize(DB.iconSize - 2, DB.iconSize - 2)
		if self.slots[i]:IsShown() then
			shownSlots = shownSlots + 1
			self.slots[i]:SetPoint("LEFT", self, ((shownSlots-1) * DB.iconSize) + ((shownSlots-1) * 4), 0)
		end
	end
	self:SetSize((shownSlots * DB.iconSize) + ((shownSlots - 1) * 4), DB.iconSize)
end

local function createSlot(self, id)
	local iconsize = DB.iconSize - 2
	local frame = CreateFrame("Button", 'myLootFrameBaseSlot'..id, self, "aLootButtonTemplate")
		frame:SetFrameLevel(self:GetFrameLevel() + 1)
		frame:SetPoint("LEFT", 8, 0)
		frame:SetSize(iconsize, iconsize)
		frame:SetID(id)
	
		frame:RegisterForClicks("LeftButtonUp", "RightButtonUp")

		frame:SetScript("OnEnter", OnEnter)
		frame:SetScript("OnLeave", OnLeave)
		frame:SetScript("OnClick", OnClick)
		frame:SetScript("OnShow", OnShow)
	
		frame.border = CreateMyBackdrop(frame, 1, 0, 0, 0, 1,"Interface\\Buttons\\WHITE8x8", 0, 0, 0, .7, 5, 0, 0, 0, 0.6)
		frame.border.shadow:Show()
	
	local iconFrame = CreateFrame("Frame", nil, frame)
		iconFrame:SetSize(iconsize, iconsize)
		iconFrame:SetAllPoints()
	
		frame.icon = iconFrame:CreateTexture(nil, "OVERLAY")
		frame.icon:SetAlpha(.8)
		frame.icon:SetTexCoord(.07, .93, .07, .93)
		frame.icon:SetAllPoints()
	
		frame.count = CreateMyText(iconFrame, "OVERLAY", nil, 16, "OUTLINE", "CENTER", "CENTER", false)
		frame.count:SetJustifyH("RIGHT")
		frame.count:SetPoint("BOTTOMRIGHT", iconFrame, -1, 2)
		frame.count:SetText(1)
		
		frame.questTexture = iconFrame:CreateTexture(nil, 'OVERLAY')
		frame.questTexture:SetPoint("TOPRIGHT", iconFrame, "TOPRIGHT", 4, 0)
		frame.questTexture:SetSize(16, 24)
		frame.questTexture:SetAtlas("questlegendary")
		frame.questTexture:Hide()
	
	self.slots[id] = frame
	return frame
end

local function UpdateSlot(self, i)
	if (LootSlotHasItem(i) or (self.AutoLootTable and self.AutoLootTable[i])) then
		local lootIcon, lootName, lootQuantity, currencyID, lootQuality, locked, isQuestItem, questID, isActive
		local coins = 0
		local slot = self.slots[i] or createSlot(self, i)
		
		if (self.AutoLootTable) then
			local entry = self.AutoLootTable[i]
			if( entry.hide ) then
				slot:Hide()
				return;
			else
				lootIcon = entry.texture
				lootName = entry.item
				lootQuantity = entry.quantity
				lootQuality = entry.quality
				locked = entry.locked
				isQuestItem = entry.isQuestIte
				questID = entry.questId
				isActive = entry.isActive
			end
		else
			lootIcon, lootName, lootQuantity, currencyID, lootQuality, locked, isQuestItem, questID, isActive = GetLootSlotInfo(i)
		end
		--[[
		if ( currencyID ) then 
			lootName, lootIcon, lootQuantity, lootQuality = CurrencyContainerUtil.GetCurrencyContainerInfo(currencyID, lootQuantity, lootName, lootIcon, lootQuality)
		end
		]]--		
		if lootIcon then
			if slot.AnimIn:IsPlaying() then
				slot.AnimIn:Stop()
			end
				
			local color = ITEM_QUALITY_COLORS[lootQuality]
			slot.lootName = lootName
					
			if coinTextureIDs[lootIcon] then
				coins = string_match(lootName, "(%d+)")
				coins = tonumber(coins)
				slot.coins = true
				if DB.gold then
					LootSlot(i)
					return
				end
			else
				slot.coins = false
			end
				
			if lootQuantity and (lootQuantity > 1) then
				slot.count:SetText(lootQuantity)
				slot.count:Show()
			elseif coins and (coins > 0) then
				slot.count:SetText(coins)
				slot.count:Show()
			else
				slot.count:Hide()
			end
							
			slot.quality = lootQuality
			if locked then
				slot.quality = 9
				slot.border.shadow:SetBackdropBorderColor(1, 0, 0)
			elseif lootQuality and (lootQuality > 1) then
				slot.border.shadow:SetBackdropBorderColor(color.r, color.g, color.b)
			else
				slot.border.shadow:SetBackdropBorderColor(0, 0, 0)
			end
					
			slot.icon:SetTexture(lootIcon)
			local questTexture = slot.questTexture
			if questID and not isActive then
				slot.quality = 5
				slot.border.shadow:SetBackdropBorderColor(1, 1, 0)
				questTexture:Show()
			elseif questID or isQuestItem then
				slot.quality = 5
				slot.border.shadow:SetBackdropBorderColor(1, 1, 0)
				questTexture:Show()
			else
				questTexture:Hide()
			end
					
			slot:Enable()
			
		else
			local slot = self.slots[1] or createSlot(self, 1)
			slot.icon:SetTexture("Interface\\Icons\\INV_Misc_Herb_AncientLichen")
			slot.count:Hide()
			slot.border.shadow:Hide()
			self:SetScript("OnUpdate", OnUpdateLootFrame)
			slot:Disable()
		end
		slot:Show()
		slot.border:Hide()
		slot.AnimIn:Play()
		
		slot.AnimIn:SetScript("OnFinished", function(self)
			self:GetParent().border:Show()
		end)
	else
		self.slots[i]:Hide()
	end
end

function OnUpdateLootFrame(self, elapsed)
	self.timeSinceUpdate = (self.timeSinceUpdate or 0) + elapsed
	if( self.AutoLootTable )then
		if( self.AutoLootDelay > 0 ) then
			self.AutoLootDelay = self.AutoLootDelay - elapsed
			self.timeSinceUpdate = 0
			self.AutoLootCurrentIdx = 1
		elseif( self.timeSinceUpdate >  LOOTFRAME_AUTOLOOT_RATE ) then
			local entry = self.AutoLootTable[self.AutoLootCurrentIdx]
			if( entry and not entry.roll and not entry.locked) then
				self.AutoLootTable[self.AutoLootCurrentIdx].hide = true
			end
			self.AutoLootCurrentIdx = self.AutoLootCurrentIdx +1
			self.timeSinceUpdate = 0
			if( self.AutoLootCurrentIdx > #self.AutoLootTable ) then
				self:SetScript("OnUpdate", nil)
				self.timeSinceUpdate = nil
				self.AutoLootTable = nil
				OnLootClosed(self)
			end
		end
	elseif ( self.timeSinceUpdate >= LOOT_UPDATE_INTERVAL ) then
		self:SetScript("OnUpdate", nil)
		self.timeSinceUpdate = nil
		for i = 1, self.numLootItems do
			UpdateSlot(self, i)
		end
	end
end

local function OnLootOpened(self, ...)
	local autoLoot, isFromItem = ...
	self.numLootItems = 0
	
	if( autoLoot ) then
		if( not self.AutoLootTable )then
			self.AutoLootTable = GetLootInfo()
		end
		self:SetScript("OnUpdate", OnUpdateLootFrame)
		self.AutoLootDelay = LOOTFRAME_AUTOLOOT_DELAY
	else
		self.AutoLootDelay = 0
		self.AutoLootTable = nil
	end
	
	-- koli moznemu move frame
	if DB.move then
		print("|cffFF0000LOCK|r move lootFrame v OnLootOpened\n")
		self:EnableMouse(false)
		self.value:Hide()
		self.border:Hide()
		DB.move = false
	end

	self:Show()
	
	if not self:IsShown() then
		CloseLoot(not autoLoot)
	else
		if ( isFromItem ) then
			PlaySound(SOUNDKIT.UI_CONTAINER_ITEM_OPEN)
		end
	end
	
	-- ak je zapnuty loot na mieste kurzora
	if C_CVar.GetCVarBool("lootUnderMouse") then
		local x, y = GetCursorPosition()
		x = x / self:GetEffectiveScale()
		y = y / self:GetEffectiveScale()

		self:ClearAllPoints()
		self:SetPoint("TOPLEFT", nil, "BOTTOMLEFT", x - (DB.iconSize / 2), y + (DB.iconSize / 2))
		self:GetCenter()
		self:Raise()
	else
		--self:ClearAllPoints()
		--self:SetPoint("CENTER", UIParent, "CENTER", 0, 100)		
	end
	
	if( self.AutoLootTable ) then
		self.numLootItems = #self.AutoLootTable
	else
		self.numLootItems = GetNumLootItems()
	end
	
	if self.numLootItems > 0 then
		for i = 1, self.numLootItems do
			UpdateSlot(self, i)
		end
	end
	
	--self:SetSize((self.numLootItems * DB.iconSize) + ((self.numLootItems - 1)* 4), DB.iconSize)
	anchorSlots(self)
end

local function OnLootReady(myLootFrameBase, ...)
	if DB.speed then
		if C_CVar.GetCVarBool("autoLootDefault") ~= IsModifiedClick("AUTOLOOTTOGGLE") then
			for i = GetNumLootItems(), 1, -1 do
				LootSlot(i)
			end
		end
	end
end

local function OnLootSlotCleared(self, ...)
	local slot = ...
	if not self:IsShown() then return end
	if self.slots[slot] then
		self.slots[slot]:Hide()
	end
	anchorSlots(self)
end

local function myLootFrameBase_OnShow(self)
	if( self.numLootItems == 0 ) then
		PlaySound(SOUNDKIT.LOOT_WINDOW_OPEN_EMPTY)
	elseif( IsFishingLoot() ) then
		PlaySound(SOUNDKIT.FISHING_REEL_IN)
	end
end

local function myLootFrameBase_OnHide(self)
	CloseLoot()
	StaticPopup_Hide('CONFIRM_LOOT_DISTRIBUTION')
	
	MasterLooterFrame:Hide()

	if( self.AutoLootTable )then
		self:SetScript("OnUpdate", nil)
		self.timeSinceUpdate = nil
		self.AutoLootTable = nil
	end
end

local function OnAddonLoaded(self, ...)
	local name = ...
	if name == _ then
		-- DB
		local defaultsDB = {
			speed = false,
			gold = true,
			move = false,
			iconSize = 48,
		}
		
		if not _G["DB"] then _G["DB"] = defaultsDB end
		DB = _G["DB"]
				
		local lootFrameBase = CreateFrame("Frame", "myLootFrameBase", UIParent)
		lootFrameBase:SetFrameStrata(_G.LootFrame:GetFrameStrata())
		lootFrameBase:SetFrameLevel(_G.LootFrame:GetFrameLevel())
		lootFrameBase:SetPoint("CENTER", UIParent, "CENTER", 0, 100)
		lootFrameBase:SetSize(DB.iconSize, DB.iconSize)
		lootFrameBase:SetScale(1)
		lootFrameBase:Hide()
		lootFrameBase.slots = {}
		
		lootFrameBase.border = CreateMyBackdrop(lootFrameBase, 1, 0, 0, 0, 1,"Interface\\Buttons\\WHITE8x8", 0, 0, 0, .7, 4, 0, 0, 0, 0.6)
		lootFrameBase.border:Hide()
		
		lootFrameBase.value = CreateMyText(lootFrameBase, "OVERLAY", nil, 10, "OUTLINE", "CENTER", "CENTER", false)
		lootFrameBase.value:SetPoint("CENTER", lootFrameBase, "CENTER", 0, 0)
		lootFrameBase.value:SetText("L-move\nR-close")
		lootFrameBase.value:Hide()
		
		lootFrameBase:SetMovable(true)
		lootFrameBase:SetClampedToScreen(true)
		lootFrameBase:SetScript("OnDragStart", function(self) self:StartMoving() end)
		lootFrameBase:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
		lootFrameBase:RegisterForDrag("LeftButton")
		
		lootFrameBase:SetMouseClickEnabled(true)
		lootFrameBase:SetScript("OnMouseDown", function(self, button)
			if button == "RightButton" then --and not InCombatLockdown() then
				print("|cffFF0000LOCK|r move lootFrame\n")
				self:EnableMouse(false)
				self.value:Hide()
				self.border:Hide()
				self:Hide()
				DB.move = false
			end
		end)
		
		lootFrameBase:SetScript("OnShow", lootFrameBase_OnShow)
		lootFrameBase:SetScript("OnHide", lootFrameBase_OnHide)
		
		_G.LootFrame:UnregisterAllEvents()
		tinsert(_G.UISpecialFrames, "lootFrameBase")
		
		-- Slash handler
		SLASH_ALOOT1 = "/aloot"
		SlashCmdList["ALOOT"] = function(msg)
			local _, _, cmd, args = string.find(msg, "%s?(%w+)%s?(.*)")
			if ( cmd == "speed" ) then
				if DB.speed then
					print("|cff00bbffSpeed loot is disabled.|r")
					DB.speed = false
				else
					print("|cff00bbffSpeed loot is enabled.|r")
					DB.speed = true
					if C_CVar.GetCVarBool("autoLootDefault") then
						print("|cff00bbff- your autoloot is enabled, use any MOD key to block speed loot|r")
					else
						print("|cff00bbff- your autoloot is disabled, use any MOD key to speed loot|r")
					end
				end
				
			elseif ( cmd == "gold" ) then
				if DB.gold then
					print("|cff00bbffSpeed gold loot is disabled.|r")
					DB.gold = false
				else
					print("|cff00bbffSpeed gold loot is enabled.|r")
					DB.gold = true
				end
				
			elseif ( cmd == "move" ) then
				if not DB.move then
					print("|cff00FF00UNLOCK|r move lootFrame\n")
					myLootFrameBase:EnableMouse(true)
					myLootFrameBase:SetSize(DB.iconSize, DB.iconSize)
					myLootFrameBase.value:Show()
					myLootFrameBase.border:Show()
					myLootFrameBase:Show()
					DB.move = true
				end
			elseif ( cmd == "size" and args ~= nil ) then
				if tonumber(args) then
					args = tonumber(args)
					if args > 23 and args < 101 then
						DB.iconSize = args
						-- zmen uz u existujucich slotov
						anchorSlots(myLootFrameBase)
						print("|cff00FF00Icon size|r is changed to "..DB.iconSize.."\n")
					else
						print("|cff00FF00Icon size|r "..args.." is out of range\n")
					end
				else
					print("|cff00FF00Icon size|r is not number\n")
				end
			else
				print("|cff00bbffSlash commands|r :\n")
				print("|cff00bbff/aloot speed|r - loot all item, dont loading lootframe, now ", DB.speed and "|cff00ff00ENABLED|r" or "|cffff0000DISABLED|r", "\n")
				print("|cff00bbff/aloot gold|r - loot only golds instantly, now ", DB.gold and "|cff00ff00ENABLED|r" or "|cffff0000DISABLED|r", "\n")
				print("|cff00bbff/aloot size number|r - change iconsize (24-100)\n")
				print("|cff00bbff/aloot move|r - enable drag for move lootFrame window")
				
			end
		end
		
		if IsAddOnLoaded(_) then
			self:UnregisterEvent('ADDON_LOADED')
			self.ADDON_LOADED = nil
		end
	end
end



function lootFrameMixin:OnEvent(event, ...)
	if ( event == "ADDON_LOADED" ) then
		OnAddonLoaded(self, ...)
	
	elseif ( event == "PLAYER_LOGIN" ) then
		--print(event)
		
	elseif ( event == "LOOT_READY" ) then
		OnLootReady(myLootFrameBase, ...)
		
	elseif ( event == "LOOT_OPENED" ) then
		OnLootOpened(myLootFrameBase, ...)
		
	elseif ( event == "LOOT_SLOT_CLEARED" ) then
		OnLootSlotCleared(myLootFrameBase, ...)
		
	elseif ( event == "LOOT_CLOSED" ) then
		if( not myLootFrameBase.AutoLootTable ) then
			OnLootClosed(myLootFrameBase)
		end
		
	elseif ( event == "OPEN_MASTER_LOOT_LIST" ) then
		ToggleDropDownMenu(1, nil, GroupLootDropDown, LootFrame.selectedLootButton, 0, 0)		--LootFrame.selectedSlot
			
	elseif ( event == "UPDATE_MASTER_LOOT_LIST" ) then
		MasterLooterFrame_UpdatePlayers()
	end
end

function lootFrameMixin:OnLoad()
	for _, event in pairs({
		"ADDON_LOADED",
		"PLAYER_LOGIN",
		"LOOT_READY",
		"LOOT_OPENED",
		"LOOT_SLOT_CLEARED",
		"LOOT_CLOSED",
		--"OPEN_MASTER_LOOT_LIST",
		--"UPDATE_MASTER_LOOT_LIST",
	}) do self:RegisterEvent(event) end
	lootFrameMixin = nil
end
